feat(cccl): integrate missing CCCL directories — python/, ci/, .agent/, docs/, test/
Sparse-checkout from NVIDIA/cccl main branch to complete cccl_upstream: Added: - python/cuda_cccl/ (226 files) — Python bindings for device-level algorithms Critical for muh toolchain: cuda.compute.reduce_into, scan, radix_sort, etc. Includes 204 .py files with full test coverage for all 27 algorithms - ci/ (163 files) — Build/test infrastructure build_cub.sh, test_cub.sh, build_and_test_targets.sh, matrix.yaml Directly maps to our [INFRA-CI] and [INFRA-BUILD] items - .agent/skills/ (7 files) — NVIDIA's own agent skills for CCCL cccl-style/SKILL.md, cccl-test/SKILL.md, sass-diff/SKILL.md - docs/ (491 files) — Official CCCL documentation CI references, CMake guides, Python compute docs, libcudacxx PTX docs - test/ (12 files) — Top-level integration tests (cuda_smoke, stdpar) - Root configs: .clang-format, .clang-tidy, CONTRIBUTING.md, pyproject.toml - CLAUDE.md symlink → AGENTS.md (NVIDIA's standard) cccl_upstream now mirrors full NVIDIA/cccl structure: Before: 42M (cub + thrust + libcudacxx + cudax + c + examples + benchmarks) After: 53M (+python +ci +docs +.agent +test +configs) This completes the CCCL base needed for: - [muh-bench] items: ci/util/build_and_test_targets.sh for targeted builds - [CCCL-verify] items: python/cuda_cccl/tests/ as reference implementations - [CCCL-test] items: ci/test_cub.sh, ci/test_thrust.sh - Agent workflow: .agent/skills/ for consistent style and test patterns
This commit is contained in:
60
cccl_upstream/docs/libcudacxx/extended_api/math/ipow.rst
Normal file
60
cccl_upstream/docs/libcudacxx/extended_api/math/ipow.rst
Normal file
@@ -0,0 +1,60 @@
|
||||
.. _libcudacxx-extended-api-math-ipow:
|
||||
|
||||
``cuda::ipow``
|
||||
====================================
|
||||
|
||||
Defined in the ``<cuda/cmath>`` header.
|
||||
|
||||
.. code:: cuda
|
||||
|
||||
namespace cuda {
|
||||
|
||||
template <typename T, typename E>
|
||||
[[nodiscard]] __host__ __device__ constexpr
|
||||
T ipow(T base, E exp) noexcept;
|
||||
|
||||
} // namespace cuda
|
||||
|
||||
The function computes the integer ``base`` raised to the power of ``exp``.
|
||||
|
||||
**Parameters**
|
||||
|
||||
- ``base``: The base value.
|
||||
- ``exp``: The exponent value.
|
||||
|
||||
**Return value**
|
||||
|
||||
- The result of raising ``base`` to the power of ``exp``. If ``exp`` is negative, the result is 0.
|
||||
|
||||
**Constraints**
|
||||
|
||||
- ``T`` is an integer type.
|
||||
- ``E`` is an integer type.
|
||||
|
||||
**Preconditions**
|
||||
|
||||
- if ``base`` is 0, then ``exp`` must be non-negative.
|
||||
|
||||
Example
|
||||
-------
|
||||
|
||||
.. code:: cuda
|
||||
|
||||
#include <cuda/cmath>
|
||||
#include <cuda/std/cassert>
|
||||
|
||||
__global__ void ipow_kernel() {
|
||||
assert(cuda::ipow(0, 0) == 1);
|
||||
assert(cuda::ipow(2, 2) == 4);
|
||||
assert(cuda::ipow(99, 1) == 99);
|
||||
assert(cuda::ipow(4, 7) == 16384);
|
||||
assert(cuda::ipow(-1, 3) == -1);
|
||||
assert(cuda::ipow(23, -1) == 0);
|
||||
}
|
||||
|
||||
int main() {
|
||||
ipow_kernel<<<1, 1>>>();
|
||||
cudaDeviceSynchronize();
|
||||
}
|
||||
|
||||
`See it on Godbolt 🔗 <https://godbolt.org/z/TMacWvz8v>`__
|
||||
Reference in New Issue
Block a user